<?php
/*
Plugin Name: WP Preset
Plugin URI: 
Description: This is a simple preset for wordpress.
Author: Takuma Ando
Version: 0.1.2
Author URI: 
*/

define( 'WP_PRESET_JSON', dirname(__FILE__) . '/wp-preset.json' );

function wp_preset_dashboard_meta_boxes() {
	static $meta_boxes = array(
		'normal' => array(
			'dashboard_browser_nag',
			'dashboard_right_now',
			'dashboard_recent_comments',
			'dashboard_incoming_links',
			'dashboard_plugins',
			'dashboard_activity',
		),
		'side' => array(
			'dashboard_quick_press',
			'dashboard_recent_drafts',
			'dashboard_primary',
			'dashboard_secondary',
		),
	);
	return $meta_boxes;
}

function wp_preset_menus() {
	static $menus = array(
		'media' => 'upload.php',
		'comment' => 'edit-comments.php',
		'link' => 'link-manager.php',
		'post' => 'edit.php',
		'page' => 'edit.php?post_type=page',
		'discussion' => 'options-discussion.php',
	);
	return $menus;
}

function wp_preset_shortcodes() {
	static $shortcodes = array(
		'bloginfo'                 => 'Same as \'get_bloginfo($arg)\'',
		'template_directory_uri'   => 'Same as \'get_template_directory_uri()\'',
		'stylesheet_directory_uri' => 'Same as \'get_stylesheet_directory_uri()\'',
	);
	return $shortcodes;
}

function wp_preset_headers() {
	static $headers = array(
		'wlwmanifest_link',
		'rsd_link',
		'wp_generator',
	);
	return $headers;
}

function wp_preset_load_json() {
	static $json;
	if( empty($json) )
		$json = json_decode(get_option('wp-preset'));
	return $json;
}

function wp_preset_checked( $key ) {
	$json = wp_preset_load_json();
	echo !empty($json->{$key}) ? ' checked="checked" ' : '';
}

function wp_preset_value( $key ) {
	$json = wp_preset_load_json();
	echo !empty($json->{$key}) ? $json->{$key} : '';
}

function wp_preset_selected( $key ) {
	$json = wp_preset_load_json();
	echo !empty($json->{$key}) ? ' selected="selected" ' : '';
}




add_action( 'init', 'wp_preset_init' );
function wp_preset_init() {
	$json = wp_preset_load_json();
	
	foreach( array_keys(wp_preset_shortcodes()) as $code ) {
		if( !empty($json->{'shortcode_'.$code}) )
			add_shortcode( $code, 'wp_preset_shortcode_' . $code );
	}
	
	foreach( wp_preset_headers() as $header ) {
		if( !empty($json->{'remove_'.$header}) )
			remove_action('wp_head', $header);
	}
}

function wp_preset_shortcode_bloginfo( $arg = 'name' ){
	if( is_array($arg) )
		$arg = array_shift($arg);
	return get_bloginfo($arg);
}

function wp_preset_shortcode_template_directory_uri(){
	return get_template_directory_uri();
}

function wp_preset_shortcode_stylesheet_directory_uri(){
	return get_stylesheet_directory_uri();
}




add_action( 'admin_init', 'wp_preset_admin_init' );
function wp_preset_admin_init() {
	$json = wp_preset_load_json();
	
	if( !empty( $_POST['_wp_preset_save'] ) ) {
		$data = array();
		foreach( wp_preset_dashboard_meta_boxes() as $options ) {
			foreach( $options as $option ) {
				$data['remove_'.$option] = (int) !empty($_POST['remove_'.$option]);
			}
		}
		foreach( array_keys(wp_preset_menus()) as $menu ) {
			$data['remove_'.$menu] = (int) !empty($_POST['remove_'.$menu]);
		}
		foreach( array_keys(wp_preset_shortcodes()) as $code ) {
			$data['shortcode_'.$code] = (int) !empty($_POST['shortcode_'.$code]);
		}
		
		$data['dashboard_content_show']   = (int) !empty($_POST['dashboard_content_show']);
		$data['dashboard_title']   = @$_POST['dashboard_title'];
		$data['dashboard_content'] = @$_POST['dashboard_content'];
		
		foreach( wp_preset_headers() as $header ) {
			$data['remove_'.$header] = (int) !empty($_POST['remove_'.$header]);
		}
		
		update_option('wp-preset', json_encode($data));
		wp_redirect($_SERVER['REQUEST_URI'], 302);
		exit;
	}
	
	foreach(wp_preset_dashboard_meta_boxes() as $position => $options) {
		foreach($options as $option) {
			if( !empty($json->{'remove_'.$option}) ) {
				remove_meta_box( $option, 'dashboard', $position );
			}
		}
	}
	
	
}

add_action( 'wp_dashboard_setup', 'wp_preset_add_meta_boxes_dashboard' );
function wp_preset_add_meta_boxes_dashboard() {
	$json = wp_preset_load_json();
	if( !empty( $json->dashboard_content_show ) )
		add_meta_box( 'wp_preset_text', $json->dashboard_title, 'wp_preset_dashboard_content', 'dashboard', 'normal', 'high' );
}

function wp_preset_dashboard_content() {
	$json = wp_preset_load_json();
	if( !empty( $json->dashboard_content ) )
		echo $json->dashboard_content;
}



add_action('admin_head', 'wp_preset_admin_head');
function wp_preset_admin_head(){
	global $wp_post_types, $menu, $submenu;
	$json = wp_preset_load_json();
	
	foreach( wp_preset_menus() as $key => $link ) {
		if( !empty($json->{'remove_'.$key}) ) {
			foreach( $menu as $idx => $menu_arr ){
				if( $menu_arr[2] == $link )
					unset( $menu[$idx] );
			}
			foreach( $submenu as $menu_link => $submenu_items ) {
				foreach( $submenu_items as $idx => $item ) {
					if( $item[2] == $link )
						unset( $submenu[$menu_link][$idx] );
				}
			}
		}
	}
}


add_action( 'admin_menu', 'wp_preset_admin_menu' );
function wp_preset_admin_menu() {
	add_options_page( 'WP Preset', 'WP Preset', 'manage_options', 'wp_preset_plugin_page', 'wp_preset_plugin_page');
}

function wp_preset_plugin_page() { ?>

<h2>WP Preset</h2>

<form method="post" action="<?php echo $_SERVER['REQUEST_URI'] ?>" novalidate="novalidate">
	<input type="hidden" name="_wp_preset_save" value="1" />
	<table class="form-table">
		<tbody>
			<tr>
				<th scope="row">デフォルトダッシュボード項目の削除</th>
				<td>
					<?php foreach(wp_preset_dashboard_meta_boxes() as $options) : foreach($options as $option) :
																								$key = "remove_{$option}" ?>
					<label>
						<input name="<?php echo $key ?>" type="checkbox" value="1"<?php wp_preset_checked( $key ) ?>>
						<?php echo $option ?>
					</label><br />
					<?php endforeach; endforeach; ?>
				</td>
			</tr>
			<tr>
				<th scope="row">ダッシュボードに特定の内容を表示</th>
				<td>
					<label>
						<input name="dashboard_content_show" type="checkbox" value="1"<?php wp_preset_checked( 'dashboard_content_show' ) ?>>
						表示する
					</label><br/>
					<label>タイトル</label><br/>
					<input name="dashboard_title" type="text" value="<?php wp_preset_value( 'dashboard_title' ) ?>"><br/><br/>
					<label>内容</label><br/>
					<textarea name="dashboard_content" class="regular-text"><?php wp_preset_value('dashboard_content') ?></textarea>
				</td>
			</tr>
			<tr>
				<th scope="row">デフォルトメニュー項目の削除</th>
				<td>
					<?php foreach(array_keys(wp_preset_menus()) as $menu) : $key = "remove_{$menu}" ?>
					<label>
						<input name="<?php echo $key ?>" type="checkbox" value="1"<?php wp_preset_checked( $key ) ?>>
						<?php echo $menu ?>
					</label><br />
					<?php endforeach ?>
				</td>
			</tr>
			<tr>
				<th scope="row">デフォルトヘッダ項目の削除</th>
				<td>
					<?php foreach(wp_preset_headers() as $header) : $key = "remove_{$header}" ?>
					<label>
						<input name="<?php echo $key ?>" type="checkbox" value="1"<?php wp_preset_checked( $key ) ?>>
						<?php echo $header ?>
					</label><br />
					<?php endforeach ?>
				</td>
			</tr>
			<tr>
				<th scope="row">ショートコード</th>
				<td>
					<?php foreach(wp_preset_shortcodes() as $code => $description) : $key = "shortcode_{$code}" ?>
					<p><label>
						<input name="<?php echo $key ?>" type="checkbox" value="1"<?php wp_preset_checked( $key ) ?>>
						<?php echo $code ?>
					</label></p>
					<p class="description"><?php echo $description ?><br /></p>
					<?php endforeach ?>
				</td>
			</tr>
		</tbody>
	</table>
	<p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary" value="変更を保存"></p>
</form>

<?php }

